// 云函数入口文件
const cloud = require('wx-server-sdk')
const addMinutes = require('date-fns/addMinutes');
cloud.init()
const db = cloud.database();
// 云函数入口函数
exports.main = async (event, context) => {
  switch (event.action) {
    case 'addOrder': {
      return addOrder(event)
    }
    case 'updateOrder': {
      return updateOrder(event)
    }
    case 'findAllOrderList':{
      return findAllOrderList(event)
    }
    case 'findOrderDetail':{
      return findOrderDetail(event)
    }
    default: {
      return
    }
  }

}

async function addOrder(event){
  const wxContext = cloud.getWXContext()
  const  OPENID= wxContext.OPENID;
  const orderNo = await createOrderNo();
  // 添加订单
  /**
   * 将食品添加到订单中，更新order表
   */
  const orderResult = await db.collection('order').add({
    data:{
      _openid:OPENID,
      orderNo, //订单编号
      order_amount: event.order_amount, // 订单总金额
      order_state: 0, // 0 表示未完成 1表示已取消 2表示已完成
      pay_mode:1, // 默认微信支付
      pay_state:1, // 1待付款 2、已付款
      phone:event.phone,//订单联系方式
      remark:event.remark,//订单备注
      take_food_time: event.take_food_time == '1' ? new Date() : addMinutes(new Date(2014, 6, 10, 12, 0), Number(event.take_food_time)),//取餐时间
      take_food_way: Number(event.take_food_way),// 取餐方式  堂食 || 外带
      create_time: new Date() // 下单时间
    }
  });
  if(orderResult.errMsg == 'collection.add:ok'&&orderResult._id){
    let add = [];
    console.log(event.foodList)

    for(var i=0;i<event.foodList.length;i++){
      var food = event.foodList[i];
      let orderDetail = await db.collection('orderStatement').add({
        data:{
          order_id: orderResult._id,
          food_id: food._id,
          food_count: food.out_count,
          food_total_price: food.out_count * food.price,
          food_name: food.name
        }
      });
      if (orderDetail.errMsg == 'collection.add:ok' && orderDetail._id){
        add.push(true);
      }else{
        add.push(false);
      }
    }

    if( add.length!==0&& add.every(v=>v == true)){
      return {
        code:1,
        data: { order_id: orderResult._id, order_price: event.order_amount},
        msg:'订单生成成功'
      }
    }else{
      return {
        code: 0,
        data: null,
        msg: '订单生成失败'
      }
    }
  
  }else{
    return {
      code: 0,
      data: null,
      msg: '订单生成失败'
    }
  }
  
}

/**
 * 参数order_id pay_state order_state
 * 更新订单状态、支付状态
 */
async function updateOrder(event){
  try{
    const result = await db.collection('order').doc(event.order_id).update({
      data:{
        order_state:Number(event.order_state),
        pay_state:Number(event.pay_state)
      }
    });
    console.log(result)
    if(result.errMsg == 'document.update:ok' && result.stats.updated == 1){
      return {
        code:1,
        data:event.order_id,
        msg:'更新成功'
      }
    }

    return {
      code: 0,
      data: null,
      msg: '更新失败'
    }
  }catch(e){
    return {
      code: 0,
      data: null,
      msg: '更新失败'
    }
  }
}


/**
 * 生产订单编号
 */
async function createOrderNo(){
 //1、获取数据库中所有订单的单号，进行排序
 //2、判断如果有单号，取出最后一个单号,否则赋值
 //3、用substr方法截取出除了时间后的字符串转为数字
 //4、将该数字自增，转为字符串
 //5、生成单号
  const result = await db.collection('order').field({
    orderNo:true
  }).orderBy('orderNo','asc').get();
  let orderNo = null;
  if(result.errMsg == 'collection.get:ok'){
    if(result.data.length ==0){
      orderNo = 'DC'+ new Date().getTime()+'100';
    }else{
      const len = result.data.length;
      const lastOrderNo = result.data[len-1].orderNo;// 最大单号
      let num = Number(lastOrderNo.substr(15, 3));
      num+=1;
      orderNo = 'DC'+new Date().getTime()+num;
    }
  }
  return orderNo;
}
/**
 * 根据订单order_id 获取订单详情
 */
async function findOrderDetail(event){
  try{
    const orderResult = await db.collection('order').doc(event.order_id).get(); // 获取订单信息
    const orderStatementResult = await db.collection('orderStatement').where({
      order_id:event.order_id
    }).get(); // 查询订单对应的商品

    console.log(orderResult);
    console.log(orderStatementResult)

    if (orderResult.errMsg == 'document.get:ok'&& orderStatementResult.errMsg == 'collection.get:ok'){
      var data = {
         ...orderResult.data,
         menuList:[...orderStatementResult.data]
      }

      return {
        code:1,
        data,
        msg:'查询订单详情成功'
      }
    }
    return {
      code: 0,
      data,
      msg: '查询订单详情失败'
    }
  }catch(e){
    return {
      code: 0,
      data,
      msg: '查询订单详情失败'
    }
  }
}
/**
 * 查询用户所有订单信息
 */
async function findAllOrderList(){
  const openid = cloud.getWXContext().OPENID;
  try{
    const result = await db.collection('order').where({
      _openid:openid
    }).get()

    if(result.errMsg == 'collection.get:ok'){
      return {
        code:1,
        data:result.data,
        msg:'订单查询成功'
      }
    }
    return {
      code: 0,
      data: null,
      msg: '订单查询失败'
    }
  }catch(e){
    return {
      code: 0,
      data: null,
      msg: '订单查询失败'
    }
  }
}