//app.js
App({
  onLaunch: function() {
    // this.login();

    if (!wx.cloud) {
      console.error('请使用 2.2.3 或以上的基础库以使用云能力')
    } else {
      wx.cloud.init({
        // env 参数说明：
        //   env 参数决定接下来小程序发起的云开发调用（wx.cloud.xxx）会默认请求到哪个云环境的资源
        //   此处请填入环境 ID, 环境 ID 可打开云控制台查看
        //   如不填则使用默认环境（第一个创建的环境）
        // env: 'my-env-id',
        traceUser: true,
      })
    }
    this.checkLogin();
    this.globalData = {
      WINDOWWIDTH: wx.getSystemInfoSync().windowWidth,
      WINDOWHEIGHT: wx.getSystemInfoSync().windowHeight,
      userInfo: wx.getStorageSync('userInfo'),
      isLogin:false,
      categories:[]
    }

  },
  onOpenLocation(location) {
    const latitude = location[1]; // 纬度
    const longitude = location[0]; //经度
    wx.openLocation({
      latitude,
      longitude,
      scale: 18
    })

  },
  calling(phoneNum) {
    wx.makePhoneCall({
      phoneNumber: phoneNum,
      success: () => {
        console.log('成功')
      },
      fail: () => {
        console.log('失败')
      }
    })
  },
  /**
   * 选择定位信息
   */
  chooseLocation(params,callback={}) {
    wx.chooseLocation({
      latitude: params.latitude,
      longitude: params.longitude,
      success: function(res) {
        if (res.errMsg == 'chooseLocation:ok'){
          if(typeof callback.success == 'function') callback.success(res);
        }
      },
      fail(){
        if (typeof callback.fail == 'function') callback.fail();
      }
    })
  },
  getCategories(){
    const that = this;
    wx.cloud.callFunction({
      name: 'categories',
      data: {
        action: 'find'
      },
      success(res) {
        if (res.result.code == 1) {
          that.globalData.categories = res.result.data;
          wx.setStorageSync('categories', that.globalData.categories);
        }
      },
      fail() {
        console.log('查询分类失败');
      }
    })
  },
  getShopInfo(callback) {
    wx.getStorage({
      key: 'shopInfo',
      success: function(res) {
        if (res.data) {
          const result = res.data;
          callback(result);
        }
      },
      fail: () => {

        wx.cloud.callFunction({
          name: 'shop',
          data: {
            action:'find'
          },
          success: (res) => {
            if(res.result.code == 1){
              const result =res.result.data;
              wx.setStorage({
                key: 'shopInfo',
                data: result
              });
              callback(result);
            }
          }
        })
      }
    })
  },
  bindGetUserInfo: function(e) {
    if (e.detail.userInfo) {
      //用户按了允许授权按钮
      var that = this;
      // 获取到用户的信息了，打印到控制台上看下
      console.log("用户的信息如下：");
      console.log(e.detail.userInfo);
      const userInfo = e.detail.userInfo;
      this.login(userInfo,function(code){
        // 登录态
        wx.cloud.callFunction({
          name: 'login',
          data: {
            code,
            nickName: userInfo.nickName,
            avatarUrl: userInfo.avatarUrl,
            gender: userInfo.gender,
            province: userInfo.province,
            city: userInfo.city
          },
          success(res) {
            console.log(res); 
            //登录成功
            if (res.result.code == 1) {
              that.globalData.userInfo = res.result.data;
              wx.setStorageSync('userInfo', res.result.data);
              that.getCategories();
              that.globalData.isLogin = true;
              wx.navigateTo({
                url: '../index/index'
              });
  
            }
          }
        })
      });
    } else {
      //用户按了拒绝按钮
      wx.showModal({
        title: '警告',
        content: '您点击了拒绝授权，将无法进入小程序，请授权之后再进入!!!',
        showCancel: false,
        confirmText: '返回授权',
        success: function(res) {
          // 用户没有授权成功，不需要改变 isHide 的值
          if (res.confirm) {
            console.log('用户点击了“返回授权”');
          }
        }
      });
    }
  },
  login(userInfo, callback) {
    const that = this;
    wx.login({
      success(res) {
        // 微信登录成功，查询用户是否授权，如果授权获取用户信息，否则跳转到授权页面
        if (res.code) {
          if (callback) {
            callback(res.code);
          } else {
          that.getSetting().then(isAuth=>{
            if (isAuth == 'success'){
              wx.getUserInfo({
                success: (user) => {
                  userInfo = user.userInfo;
                  // 登录态
                  wx.cloud.callFunction({
                    name: 'login',
                    data: {
                      code: res.code,
                      nickName: userInfo.nickName,
                      avatarUrl: userInfo.avatarUrl,
                      gender: userInfo.gender,
                      province: userInfo.province,
                      city: userInfo.city
                    },
                    success(result) {
                      console.log(result);
                      //登录成功
                      if (result.code == 1) {
                        that.globalData.userInfo = result.data;
                        wx.setStorageSync('userInfo', result.data);
                      }
                    }
                  })
                },
                fail: () => {

                }
              })
            }else{
              wx.reLaunch({
                url: '../auth/auth'
              })
            }
          })
          }
        } else {
          console.log('登录失败！' + res.errMsg)
        }
      },
      fail: () => console.error('登录失败')
    })
  },
  /**
   * 检查session_key是否过期
   */
  checkSession(callback={}) {
    const that = this;
    wx.checkSession({
      success(res) {
        //session_key 未过期，并且在本生命周期一直有效
        // 获取缓存中的用户信息
        if(typeof callback.success == 'function') callback.success();
      },
      fail() {
        console.error('session_key过期')
        // session_key 已经失效，需要重新执行登录流程
        // wx.login() //重新登录
    
        if (typeof callback.fail == 'function') callback.fail();
      }
    })
  },
  checkLogin(callback={}){
    var that =this;
    this.checkSession({
      success(){
        if(that.globalData.userInfo){
          that.globalData.isLogin = true;
        }else{
          that.login();
        }
      },
      fail(){
        that.login();
      }
    })
  },
  /**
   * 查看用户是否授权获取用户信息
   */
  getSetting() {
    const that = this;
    return new Promise((resolve, reject) => {
      wx.getSetting({
        success(res) {
          //授权
          if (res.authSetting['scope.userInfo']) {
            resolve('success');
          } else {
            resolve('fail');
          }
        },
        fail: () => {
          resolve('fail');
        }
      })
    })
  },
})