// miniprogram/pages/admin/shopInfo/shopInfo.js
const app = getApp();
Page({

  /**
   * 页面的初始数据
   */
  data: {
    region: [],
    customItem: '全部',
    bannerFiles:[],
    logoFile:null,
    shopInfo:{}
  },
  bindRegionChange: function (e) {
    console.log('picker发送选择改变，携带值为', e.detail.value)
    this.setData({
      region: e.detail.value
    })
  },
  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    const shopInfo = wx.getStorageSync('shopInfo');
    if (shopInfo){
      this.shopInfo = shopInfo;
      this.setData({
        shopInfo: shopInfo,
        logoFile: shopInfo.logo,
        bannerFiles: shopInfo.banners,
        region: [shopInfo.province, shopInfo.city, shopInfo.district]
      })
    }
  },
  // 上传图片
  doLogoUpload: function () {
    var that = this;
    // 选择图片
    wx.chooseImage({
      count: 1,
      sizeType: ['compressed'],
      sourceType: ['album', 'camera'],
      success: function (res) {

        wx.showLoading({
          title: '上传中',
        })

        const filePath = res.tempFilePaths[0]

        // 上传图片
        const cloudPath = 'shop-logo' + filePath.match(/\.[^.]+?$/)[0]
        wx.cloud.uploadFile({
          cloudPath,
          filePath,
          success: res => {
            console.log('[上传文件] 成功：', res)
            that.logoFile = res.fileID;
            that.setData({
              logoFile: res.fileID
            });

          },
          fail: e => {
            console.error('[上传文件] 失败：', e)
            wx.showToast({
              icon: 'none',
              title: '上传失败',
            })
          },
          complete: () => {
            wx.hideLoading()
          }
        })

      },
      fail: e => {
        console.error(e)
      }
    })
  },
  previewLogoImage(e){
    wx.previewImage({
      current: e.currentTarget.id, // 当前显示图片的http链接
      urls: [e.currentTarget.id] // 需要预览的图片http链接列表
    })
  },

  doBannerUpload: function () {
    var that = this;
    // 选择图片
    wx.chooseImage({
      count: 9,
      sizeType: ['original','compressed'],
      sourceType: ['album', 'camera'],
      success: function (res) {
        const filePath = res.tempFilePaths; 

        for(var i=0;i<filePath.length;i++){
          // 上传图片
          wx.showLoading({
            title: '上传中',
          })
          wx.cloud.uploadFile({
            cloudPath: 'shop-banner'+[i] + filePath[i].match(/\.[^.]+?$/)[0],
            filePath: filePath[i],
            success: res => {
              console.log('[上传文件] 成功：', res)
              if(!that.bannerFiles) that.bannerFiles = [];
              that.bannerFiles.push(res.fileID)
              console.log(that.bannerFiles);
              that.setData({
                bannerFiles: that.bannerFiles
              });

            },
            fail: e => {
              console.error('[上传文件] 失败：', e)
              wx.showToast({
                icon: 'none',
                title: '上传失败',
              })
            },
            complete: () => {
              wx.hideLoading()
            }
          })

        }
      },
      fail: e => {
        console.error(e)
      }
    })
  },
  previewBannerImage: function (e) {
    // wx.previewImage({
    //   current: e.currentTarget.id, // 当前显示图片的http链接
    //   urls: this.bannerFiles // 需要预览的图片http链接列表
    // })
    this.setData({
      show:true,
      imgUrls: this.bannerFiles,
      currentIndex: this.bannerFiles.findIndex(v => v == e.currentTarget.id)
    })
  },

  change(e) {
    console.log('current index has changed', e.detail)
  },
  deleteBanner(e) {
    console.log('delete', e.detail.url)
    const that = this;
    wx.cloud.deleteFile({
      fileList: [e.detail.url],
      success: res => {
        // handle success
        console.log(res.fileList)
        wx.showToast({
          icon: 'none',
          title: '删除成功',
        })
        that.bannerFiles = that.bannerFiles.filter(v => v !== e.detail.url);
        that.setData({
          bannerFiles: that.bannerFiles
        })
      },
      fail: err => {
        wx.showToast({
          icon: 'none',
          title: '删除失败',
        })
      },
      complete: res => {

      }
    })
  },
  hide() {
    
  },
  chooseLocation(e){
    const result = e.currentTarget.dataset;
    const that = this;
    console.log(result);
    app.chooseLocation({
      latitude: result.location.coordinates[1],
      longitude: result.location.coordinates[0],
    },{
      success(res){
        Object.assign(that.shopInfo,{
          address: res.address + res.name,
          location:{
            coordinates: [res.longitude, res.latitude]
          }
        })
        console.log(that.shopInfo);
        that.setData({
          shopInfo: that.shopInfo
        });
      },
      fail(){}
    });
  },
  formSubmit(e){
    console.log(e);
    var result =e.detail.value;
    var logoFile = this.logoFile;
    var bannerFiles = this.bannerFiles;
    wx.showLoading({
      title: '正在更新...',
    })
   
    wx.cloud.callFunction({
      name:'shop',
      data:{
        name: result.name,
        phone: result.phone,
        address: result.address,
        location: this.shopInfo.location,
        introduction: result.introduction,
        banners: bannerFiles,
        logo: logoFile,
        _id:this.shopInfo._id,
        action:'edit'
      },
      success(res){
        console.log(res);
        if(res.result.code == 1){
          wx.showToast({
            title: '更新成功',
            success(){
              wx.setStorageSync('shopInfo', res.result.data)
              wx.navigateBack();
            }
          })
         
        }else{
          wx.showToast({
            icon: 'none',
            title: '更新失败',
      
          })
        }
        
      },
      fail(error){
        console.log(error);
        wx.showToast({
          icon: 'none',
          title: '更新失败',
        })
      },
      complete: () => {
       wx.hideLoading();
      }
    })

  },
  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady: function () {

  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function () {

  },

  /**
   * 生命周期函数--监听页面隐藏
   */
  onHide: function () {

  },

  /**
   * 生命周期函数--监听页面卸载
   */
  onUnload: function () {

  },

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh: function () {

  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {

  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {

  }
})